middlenames

# XMLRésuméLibrary: User Guide

memberships | Element Reference | minor

## Name

middlenames — One or more “middle” names of a person

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `middlenames` element contains all of the names of a person, excluding their first (given) name and surname. If the person has multiple middle names, they should be space-separated.

### Parents

`middlenames` may be contained in these elements: `name`

## See Also

`firstname`, `surname`.

## Examples

    <middlenames>Samione</middlenames>

    <middlenames>Lu&iacute;s Garcia M&aacute;rquez</middlenames>

memberships | Element Reference | minor